# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tekton_pipeline.configuration import Configuration


class V1beta1TaskRunStatusFields(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cloud_events': 'list[V1beta1CloudEventDelivery]',
        'completion_time': 'V1Time',
        'pod_name': 'str',
        'resources_result': 'list[V1beta1PipelineResourceResult]',
        'retries_status': 'list[V1beta1TaskRunStatus]',
        'sidecars': 'list[V1beta1SidecarState]',
        'start_time': 'V1Time',
        'steps': 'list[V1beta1StepState]',
        'task_results': 'list[V1beta1TaskRunResult]',
        'task_spec': 'V1beta1TaskSpec'
    }

    attribute_map = {
        'cloud_events': 'cloudEvents',
        'completion_time': 'completionTime',
        'pod_name': 'podName',
        'resources_result': 'resourcesResult',
        'retries_status': 'retriesStatus',
        'sidecars': 'sidecars',
        'start_time': 'startTime',
        'steps': 'steps',
        'task_results': 'taskResults',
        'task_spec': 'taskSpec'
    }

    def __init__(self, cloud_events=None, completion_time=None, pod_name=None, resources_result=None, retries_status=None, sidecars=None, start_time=None, steps=None, task_results=None, task_spec=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1TaskRunStatusFields - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._cloud_events = None
        self._completion_time = None
        self._pod_name = None
        self._resources_result = None
        self._retries_status = None
        self._sidecars = None
        self._start_time = None
        self._steps = None
        self._task_results = None
        self._task_spec = None
        self.discriminator = None

        if cloud_events is not None:
            self.cloud_events = cloud_events
        if completion_time is not None:
            self.completion_time = completion_time
        self.pod_name = pod_name
        if resources_result is not None:
            self.resources_result = resources_result
        if retries_status is not None:
            self.retries_status = retries_status
        if sidecars is not None:
            self.sidecars = sidecars
        if start_time is not None:
            self.start_time = start_time
        if steps is not None:
            self.steps = steps
        if task_results is not None:
            self.task_results = task_results
        if task_spec is not None:
            self.task_spec = task_spec

    @property
    def cloud_events(self):
        """Gets the cloud_events of this V1beta1TaskRunStatusFields.  # noqa: E501

        CloudEvents describe the state of each cloud event requested via a CloudEventResource.  # noqa: E501

        :return: The cloud_events of this V1beta1TaskRunStatusFields.  # noqa: E501
        :rtype: list[V1beta1CloudEventDelivery]
        """
        return self._cloud_events

    @cloud_events.setter
    def cloud_events(self, cloud_events):
        """Sets the cloud_events of this V1beta1TaskRunStatusFields.

        CloudEvents describe the state of each cloud event requested via a CloudEventResource.  # noqa: E501

        :param cloud_events: The cloud_events of this V1beta1TaskRunStatusFields.  # noqa: E501
        :type: list[V1beta1CloudEventDelivery]
        """

        self._cloud_events = cloud_events

    @property
    def completion_time(self):
        """Gets the completion_time of this V1beta1TaskRunStatusFields.  # noqa: E501


        :return: The completion_time of this V1beta1TaskRunStatusFields.  # noqa: E501
        :rtype: V1Time
        """
        return self._completion_time

    @completion_time.setter
    def completion_time(self, completion_time):
        """Sets the completion_time of this V1beta1TaskRunStatusFields.


        :param completion_time: The completion_time of this V1beta1TaskRunStatusFields.  # noqa: E501
        :type: V1Time
        """

        self._completion_time = completion_time

    @property
    def pod_name(self):
        """Gets the pod_name of this V1beta1TaskRunStatusFields.  # noqa: E501

        PodName is the name of the pod responsible for executing this task's steps.  # noqa: E501

        :return: The pod_name of this V1beta1TaskRunStatusFields.  # noqa: E501
        :rtype: str
        """
        return self._pod_name

    @pod_name.setter
    def pod_name(self, pod_name):
        """Sets the pod_name of this V1beta1TaskRunStatusFields.

        PodName is the name of the pod responsible for executing this task's steps.  # noqa: E501

        :param pod_name: The pod_name of this V1beta1TaskRunStatusFields.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and pod_name is None:  # noqa: E501
            raise ValueError("Invalid value for `pod_name`, must not be `None`")  # noqa: E501

        self._pod_name = pod_name

    @property
    def resources_result(self):
        """Gets the resources_result of this V1beta1TaskRunStatusFields.  # noqa: E501

        Results from Resources built during the taskRun. currently includes the digest of build container images  # noqa: E501

        :return: The resources_result of this V1beta1TaskRunStatusFields.  # noqa: E501
        :rtype: list[V1beta1PipelineResourceResult]
        """
        return self._resources_result

    @resources_result.setter
    def resources_result(self, resources_result):
        """Sets the resources_result of this V1beta1TaskRunStatusFields.

        Results from Resources built during the taskRun. currently includes the digest of build container images  # noqa: E501

        :param resources_result: The resources_result of this V1beta1TaskRunStatusFields.  # noqa: E501
        :type: list[V1beta1PipelineResourceResult]
        """

        self._resources_result = resources_result

    @property
    def retries_status(self):
        """Gets the retries_status of this V1beta1TaskRunStatusFields.  # noqa: E501

        RetriesStatus contains the history of TaskRunStatus in case of a retry in order to keep record of failures. All TaskRunStatus stored in RetriesStatus will have no date within the RetriesStatus as is redundant.  # noqa: E501

        :return: The retries_status of this V1beta1TaskRunStatusFields.  # noqa: E501
        :rtype: list[V1beta1TaskRunStatus]
        """
        return self._retries_status

    @retries_status.setter
    def retries_status(self, retries_status):
        """Sets the retries_status of this V1beta1TaskRunStatusFields.

        RetriesStatus contains the history of TaskRunStatus in case of a retry in order to keep record of failures. All TaskRunStatus stored in RetriesStatus will have no date within the RetriesStatus as is redundant.  # noqa: E501

        :param retries_status: The retries_status of this V1beta1TaskRunStatusFields.  # noqa: E501
        :type: list[V1beta1TaskRunStatus]
        """

        self._retries_status = retries_status

    @property
    def sidecars(self):
        """Gets the sidecars of this V1beta1TaskRunStatusFields.  # noqa: E501

        The list has one entry per sidecar in the manifest. Each entry is represents the imageid of the corresponding sidecar.  # noqa: E501

        :return: The sidecars of this V1beta1TaskRunStatusFields.  # noqa: E501
        :rtype: list[V1beta1SidecarState]
        """
        return self._sidecars

    @sidecars.setter
    def sidecars(self, sidecars):
        """Sets the sidecars of this V1beta1TaskRunStatusFields.

        The list has one entry per sidecar in the manifest. Each entry is represents the imageid of the corresponding sidecar.  # noqa: E501

        :param sidecars: The sidecars of this V1beta1TaskRunStatusFields.  # noqa: E501
        :type: list[V1beta1SidecarState]
        """

        self._sidecars = sidecars

    @property
    def start_time(self):
        """Gets the start_time of this V1beta1TaskRunStatusFields.  # noqa: E501


        :return: The start_time of this V1beta1TaskRunStatusFields.  # noqa: E501
        :rtype: V1Time
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this V1beta1TaskRunStatusFields.


        :param start_time: The start_time of this V1beta1TaskRunStatusFields.  # noqa: E501
        :type: V1Time
        """

        self._start_time = start_time

    @property
    def steps(self):
        """Gets the steps of this V1beta1TaskRunStatusFields.  # noqa: E501

        Steps describes the state of each build step container.  # noqa: E501

        :return: The steps of this V1beta1TaskRunStatusFields.  # noqa: E501
        :rtype: list[V1beta1StepState]
        """
        return self._steps

    @steps.setter
    def steps(self, steps):
        """Sets the steps of this V1beta1TaskRunStatusFields.

        Steps describes the state of each build step container.  # noqa: E501

        :param steps: The steps of this V1beta1TaskRunStatusFields.  # noqa: E501
        :type: list[V1beta1StepState]
        """

        self._steps = steps

    @property
    def task_results(self):
        """Gets the task_results of this V1beta1TaskRunStatusFields.  # noqa: E501

        TaskRunResults are the list of results written out by the task's containers  # noqa: E501

        :return: The task_results of this V1beta1TaskRunStatusFields.  # noqa: E501
        :rtype: list[V1beta1TaskRunResult]
        """
        return self._task_results

    @task_results.setter
    def task_results(self, task_results):
        """Sets the task_results of this V1beta1TaskRunStatusFields.

        TaskRunResults are the list of results written out by the task's containers  # noqa: E501

        :param task_results: The task_results of this V1beta1TaskRunStatusFields.  # noqa: E501
        :type: list[V1beta1TaskRunResult]
        """

        self._task_results = task_results

    @property
    def task_spec(self):
        """Gets the task_spec of this V1beta1TaskRunStatusFields.  # noqa: E501


        :return: The task_spec of this V1beta1TaskRunStatusFields.  # noqa: E501
        :rtype: V1beta1TaskSpec
        """
        return self._task_spec

    @task_spec.setter
    def task_spec(self, task_spec):
        """Sets the task_spec of this V1beta1TaskRunStatusFields.


        :param task_spec: The task_spec of this V1beta1TaskRunStatusFields.  # noqa: E501
        :type: V1beta1TaskSpec
        """

        self._task_spec = task_spec

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1TaskRunStatusFields):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1TaskRunStatusFields):
            return True

        return self.to_dict() != other.to_dict()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tekton_pipeline
from tekton_pipeline.models.v1beta1_pipeline_run_spec import V1beta1PipelineRunSpec  # noqa: E501
from tekton_pipeline.rest import ApiException

class TestV1beta1PipelineRunSpec(unittest.TestCase):
    """V1beta1PipelineRunSpec unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test V1beta1PipelineRunSpec
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tekton_pipeline.models.v1beta1_pipeline_run_spec.V1beta1PipelineRunSpec()  # noqa: E501
        if include_optional :
            return V1beta1PipelineRunSpec(
                params = [
                    tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                        name = '0', 
                        value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                            array_val = [
                                '0'
                                ], 
                            string_val = '0', 
                            type = '0', ), )
                    ], 
                pipeline_ref = tekton_pipeline.models.v1beta1/pipeline_ref.v1beta1.PipelineRef(
                    api_version = '0', 
                    bundle = '0', 
                    name = '0', ), 
                pipeline_spec = tekton_pipeline.models.v1beta1/pipeline_spec.v1beta1.PipelineSpec(
                    description = '0', 
                    finally = [
                        tekton_pipeline.models.v1beta1/pipeline_task.v1beta1.PipelineTask(
                            conditions = [
                                tekton_pipeline.models.v1beta1/pipeline_task_condition.v1beta1.PipelineTaskCondition(
                                    condition_ref = '0', 
                                    params = [
                                        tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                                            name = '0', 
                                            value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                                array_val = [
                                                    '0'
                                                    ], 
                                                string_val = '0', 
                                                type = '0', ), )
                                        ], 
                                    resources = [
                                        tekton_pipeline.models.v1beta1/pipeline_task_input_resource.v1beta1.PipelineTaskInputResource(
                                            from = [
                                                '0'
                                                ], 
                                            name = '0', 
                                            resource = '0', )
                                        ], )
                                ], 
                            name = '0', 
                            params = [
                                tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                                    name = '0', 
                                    value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                        array_val = [
                                            '0'
                                            ], 
                                        string_val = '0', 
                                        type = '0', ), )
                                ], 
                            resources = tekton_pipeline.models.v1beta1/pipeline_task_resources.v1beta1.PipelineTaskResources(
                                inputs = [
                                    tekton_pipeline.models.v1beta1/pipeline_task_input_resource.v1beta1.PipelineTaskInputResource(
                                        name = '0', 
                                        resource = '0', )
                                    ], 
                                outputs = [
                                    tekton_pipeline.models.v1beta1/pipeline_task_output_resource.v1beta1.PipelineTaskOutputResource(
                                        name = '0', 
                                        resource = '0', )
                                    ], ), 
                            retries = 56, 
                            run_after = [
                                '0'
                                ], 
                            task_ref = tekton_pipeline.models.v1beta1/task_ref.v1beta1.TaskRef(
                                api_version = '0', 
                                bundle = '0', 
                                kind = '0', 
                                name = '0', ), 
                            task_spec = tekton_pipeline.models.v1beta1/embedded_task.v1beta1.EmbeddedTask(
                                description = '0', 
                                metadata = tekton_pipeline.models.v1beta1/pipeline_task_metadata.v1beta1.PipelineTaskMetadata(
                                    annotations = {
                                        'key' : '0'
                                        }, 
                                    labels = {
                                        'key' : '0'
                                        }, ), 
                                results = [
                                    tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                        description = '0', 
                                        name = '0', )
                                    ], 
                                sidecars = [
                                    tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                                        args = [
                                            '0'
                                            ], 
                                        command = [
                                            '0'
                                            ], 
                                        env = [
                                            None
                                            ], 
                                        env_from = [
                                            None
                                            ], 
                                        image = '0', 
                                        image_pull_policy = '0', 
                                        lifecycle = None, 
                                        liveness_probe = None, 
                                        name = '0', 
                                        ports = [
                                            None
                                            ], 
                                        readiness_probe = None, 
                                        script = '0', 
                                        security_context = None, 
                                        startup_probe = None, 
                                        stdin = True, 
                                        stdin_once = True, 
                                        termination_message_path = '0', 
                                        termination_message_policy = '0', 
                                        tty = True, 
                                        volume_devices = [
                                            None
                                            ], 
                                        volume_mounts = [
                                            None
                                            ], 
                                        working_dir = '0', )
                                    ], 
                                step_template = None, 
                                steps = [
                                    tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                                        image = '0', 
                                        image_pull_policy = '0', 
                                        lifecycle = None, 
                                        liveness_probe = None, 
                                        name = '0', 
                                        readiness_probe = None, 
                                        script = '0', 
                                        security_context = None, 
                                        startup_probe = None, 
                                        stdin = True, 
                                        stdin_once = True, 
                                        termination_message_path = '0', 
                                        termination_message_policy = '0', 
                                        timeout = None, 
                                        tty = True, 
                                        working_dir = '0', )
                                    ], 
                                volumes = [
                                    None
                                    ], 
                                workspaces = [
                                    tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                        description = '0', 
                                        mount_path = '0', 
                                        name = '0', 
                                        optional = True, 
                                        read_only = True, )
                                    ], ), 
                            timeout = None, 
                            when = [
                                tekton_pipeline.models.v1beta1/when_expression.v1beta1.WhenExpression(
                                    input = '0', 
                                    operator = '0', 
                                    values = [
                                        '0'
                                        ], 
                                    input = '0', 
                                    operator = '0', 
                                    values = [
                                        '0'
                                        ], )
                                ], 
                            workspaces = [
                                tekton_pipeline.models.v1beta1/workspace_pipeline_task_binding.v1beta1.WorkspacePipelineTaskBinding(
                                    name = '0', 
                                    sub_path = '0', 
                                    workspace = '0', )
                                ], )
                        ], 
                    params = [
                        tekton_pipeline.models.v1beta1/param_spec.v1beta1.ParamSpec(
                            default = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                array_val = [
                                    '0'
                                    ], 
                                string_val = '0', 
                                type = '0', ), 
                            description = '0', 
                            name = '0', 
                            type = '0', )
                        ], 
                    resources = [
                        tekton_pipeline.models.v1beta1/pipeline_declared_resource.v1beta1.PipelineDeclaredResource(
                            name = '0', 
                            optional = True, 
                            type = '0', )
                        ], 
                    results = [
                        tekton_pipeline.models.v1beta1/pipeline_result.v1beta1.PipelineResult(
                            description = '0', 
                            name = '0', 
                            value = '0', )
                        ], 
                    tasks = [
                        tekton_pipeline.models.v1beta1/pipeline_task.v1beta1.PipelineTask(
                            name = '0', 
                            retries = 56, 
                            timeout = None, )
                        ], 
                    workspaces = [
                        tekton_pipeline.models.v1beta1/pipeline_workspace_declaration.v1beta1.PipelineWorkspaceDeclaration(
                            description = '0', 
                            name = '0', 
                            optional = True, )
                        ], ), 
                pod_template = tekton_pipeline.models.pod/template.pod.Template(
                    affinity = None, 
                    automount_service_account_token = True, 
                    dns_config = None, 
                    dns_policy = '0', 
                    enable_service_links = True, 
                    host_network = True, 
                    image_pull_secrets = [
                        None
                        ], 
                    node_selector = {
                        'key' : '0'
                        }, 
                    priority_class_name = '0', 
                    runtime_class_name = '0', 
                    scheduler_name = '0', 
                    security_context = None, 
                    tolerations = [
                        None
                        ], 
                    volumes = [
                        None
                        ], ), 
                resources = [
                    tekton_pipeline.models.v1beta1/pipeline_resource_binding.v1beta1.PipelineResourceBinding(
                        name = '0', 
                        resource_ref = tekton_pipeline.models.v1beta1/pipeline_resource_ref.v1beta1.PipelineResourceRef(
                            api_version = '0', 
                            name = '0', ), 
                        resource_spec = tekton_pipeline.models.v1alpha1/pipeline_resource_spec.v1alpha1.PipelineResourceSpec(
                            description = '0', 
                            params = [
                                tekton_pipeline.models.v1alpha1/resource_param.v1alpha1.ResourceParam(
                                    name = '0', 
                                    value = '0', )
                                ], 
                            secrets = [
                                tekton_pipeline.models.v1alpha1/secret_param.v1alpha1.SecretParam(
                                    field_name = '0', 
                                    secret_key = '0', 
                                    secret_name = '0', )
                                ], 
                            type = '0', ), )
                    ], 
                service_account_name = '0', 
                service_account_names = [
                    tekton_pipeline.models.v1beta1/pipeline_run_spec_service_account_name.v1beta1.PipelineRunSpecServiceAccountName(
                        service_account_name = '0', 
                        task_name = '0', )
                    ], 
                status = '0', 
                task_run_specs = [
                    tekton_pipeline.models.v1beta1/pipeline_task_run_spec.v1beta1.PipelineTaskRunSpec(
                        pipeline_task_name = '0', 
                        task_pod_template = tekton_pipeline.models.pod/template.pod.Template(
                            affinity = None, 
                            automount_service_account_token = True, 
                            dns_config = None, 
                            dns_policy = '0', 
                            enable_service_links = True, 
                            host_network = True, 
                            image_pull_secrets = [
                                None
                                ], 
                            node_selector = {
                                'key' : '0'
                                }, 
                            priority_class_name = '0', 
                            runtime_class_name = '0', 
                            scheduler_name = '0', 
                            security_context = None, 
                            tolerations = [
                                None
                                ], 
                            volumes = [
                                None
                                ], ), 
                        task_service_account_name = '0', )
                    ], 
                timeout = None, 
                workspaces = [
                    tekton_pipeline.models.v1beta1/workspace_binding.v1beta1.WorkspaceBinding(
                        config_map = None, 
                        empty_dir = None, 
                        name = '0', 
                        persistent_volume_claim = None, 
                        secret = None, 
                        sub_path = '0', 
                        volume_claim_template = None, )
                    ]
            )
        else :
            return V1beta1PipelineRunSpec(
        )

    def testV1beta1PipelineRunSpec(self):
        """Test V1beta1PipelineRunSpec"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tekton_pipeline.configuration import Configuration


class V1beta1PipelineRunTaskRunStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'condition_checks': 'dict(str, V1beta1PipelineRunConditionCheckStatus)',
        'pipeline_task_name': 'str',
        'status': 'V1beta1TaskRunStatus',
        'when_expressions': 'list[V1beta1WhenExpression]'
    }

    attribute_map = {
        'condition_checks': 'conditionChecks',
        'pipeline_task_name': 'pipelineTaskName',
        'status': 'status',
        'when_expressions': 'whenExpressions'
    }

    def __init__(self, condition_checks=None, pipeline_task_name=None, status=None, when_expressions=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1PipelineRunTaskRunStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._condition_checks = None
        self._pipeline_task_name = None
        self._status = None
        self._when_expressions = None
        self.discriminator = None

        if condition_checks is not None:
            self.condition_checks = condition_checks
        if pipeline_task_name is not None:
            self.pipeline_task_name = pipeline_task_name
        if status is not None:
            self.status = status
        if when_expressions is not None:
            self.when_expressions = when_expressions

    @property
    def condition_checks(self):
        """Gets the condition_checks of this V1beta1PipelineRunTaskRunStatus.  # noqa: E501

        ConditionChecks maps the name of a condition check to its Status  # noqa: E501

        :return: The condition_checks of this V1beta1PipelineRunTaskRunStatus.  # noqa: E501
        :rtype: dict(str, V1beta1PipelineRunConditionCheckStatus)
        """
        return self._condition_checks

    @condition_checks.setter
    def condition_checks(self, condition_checks):
        """Sets the condition_checks of this V1beta1PipelineRunTaskRunStatus.

        ConditionChecks maps the name of a condition check to its Status  # noqa: E501

        :param condition_checks: The condition_checks of this V1beta1PipelineRunTaskRunStatus.  # noqa: E501
        :type: dict(str, V1beta1PipelineRunConditionCheckStatus)
        """

        self._condition_checks = condition_checks

    @property
    def pipeline_task_name(self):
        """Gets the pipeline_task_name of this V1beta1PipelineRunTaskRunStatus.  # noqa: E501

        PipelineTaskName is the name of the PipelineTask.  # noqa: E501

        :return: The pipeline_task_name of this V1beta1PipelineRunTaskRunStatus.  # noqa: E501
        :rtype: str
        """
        return self._pipeline_task_name

    @pipeline_task_name.setter
    def pipeline_task_name(self, pipeline_task_name):
        """Sets the pipeline_task_name of this V1beta1PipelineRunTaskRunStatus.

        PipelineTaskName is the name of the PipelineTask.  # noqa: E501

        :param pipeline_task_name: The pipeline_task_name of this V1beta1PipelineRunTaskRunStatus.  # noqa: E501
        :type: str
        """

        self._pipeline_task_name = pipeline_task_name

    @property
    def status(self):
        """Gets the status of this V1beta1PipelineRunTaskRunStatus.  # noqa: E501


        :return: The status of this V1beta1PipelineRunTaskRunStatus.  # noqa: E501
        :rtype: V1beta1TaskRunStatus
        """
        return self._status

    @status.setter
    def status(self, status):
        """Sets the status of this V1beta1PipelineRunTaskRunStatus.


        :param status: The status of this V1beta1PipelineRunTaskRunStatus.  # noqa: E501
        :type: V1beta1TaskRunStatus
        """

        self._status = status

    @property
    def when_expressions(self):
        """Gets the when_expressions of this V1beta1PipelineRunTaskRunStatus.  # noqa: E501

        WhenExpressions is the list of checks guarding the execution of the PipelineTask  # noqa: E501

        :return: The when_expressions of this V1beta1PipelineRunTaskRunStatus.  # noqa: E501
        :rtype: list[V1beta1WhenExpression]
        """
        return self._when_expressions

    @when_expressions.setter
    def when_expressions(self, when_expressions):
        """Sets the when_expressions of this V1beta1PipelineRunTaskRunStatus.

        WhenExpressions is the list of checks guarding the execution of the PipelineTask  # noqa: E501

        :param when_expressions: The when_expressions of this V1beta1PipelineRunTaskRunStatus.  # noqa: E501
        :type: list[V1beta1WhenExpression]
        """

        self._when_expressions = when_expressions

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1PipelineRunTaskRunStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1PipelineRunTaskRunStatus):
            return True

        return self.to_dict() != other.to_dict()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import time
from kubernetes import client, config

from tekton_pipeline.constants import constants
from tekton_pipeline.utils import utils
from tekton_pipeline.api.tekton_watch import watch as tekton_watch


class TektonClient(object):

    def __init__(self, config_file=None, context=None,
                 client_configuration=None, persist_config=True):
        """
        Tekton client constructor
        :param config_file: kubeconfig file, defaults to ~/.kube/config
        :param context: kubernetes context
        :param client_configuration: kubernetes configuration object
        :param persist_config:
        """
        if config_file or not utils.is_running_in_k8s():
            config.load_kube_config(
                config_file=config_file,
                context=context,
                client_configuration=client_configuration,
                persist_config=persist_config)
        else:
            config.load_incluster_config()
        self.core_api = client.CoreV1Api()
        self.app_api = client.AppsV1Api()
        self.api_instance = client.CustomObjectsApi()

    def create(self, entity, body, namespace=None):
        """
        Create the Tekton entity
        :param entity: the tekton entity,  currently supported values: ['task', 'taskrun', 'pipeline', 'pipelinerun', 'clustertask']. 
        :param body: Tekton entity body
        :param namespace: defaults to current or default namespace
        :return: created Tekton entity
        """
        utils.check_entity(entity)

        if namespace is None:
            namespace = utils.get_tekton_namespace(body)

        plural = str(entity).lower() + "s"

        try:
            outputs = self.api_instance.create_namespaced_custom_object(
                constants.TEKTON_GROUP,
                constants.TEKTON_VERSION,
                namespace,
                plural,
                body)
        except client.rest.ApiException as e:
            raise RuntimeError(
                "Exception when calling CustomObjectsApi->create_namespaced_custom_object:\
                 %s\n" % e)

        return outputs

    def get(self, entity, name, namespace=None, watch=False, timeout_seconds=600):
        """
        Get the Tekton objects
        :param entity: the tekton entity, currently supported values: ['task', 'taskrun', 'pipeline', 'pipelinerun'].
        :param name: existing Tekton objects
        :param namespace: defaults to current or default namespace
        :return: Tekton objects
        """

        utils.check_entity(entity)

        if namespace is None:
            namespace = utils.get_default_target_namespace()

        plural = str(entity).lower() + "s"

        if watch:
            tekton_watch(
                name=name,
                plural=plural,
                namespace=namespace,
                timeout_seconds=timeout_seconds)
        else:
            try:
                return self.api_instance.get_namespaced_custom_object(
                    constants.TEKTON_GROUP,
                    constants.TEKTON_VERSION,
                    namespace,
                    plural,
                    name)
            except client.rest.ApiException as e:
                raise RuntimeError(
                    "Exception when calling CustomObjectsApi->get_namespaced_custom_object:\
                    %s\n" % e)

    def patch(self, entity, name, body, namespace=None):
        """
        Patch existing tekton object
        :param entity: the tekton entity, currently supported values: ['task', 'taskrun', 'pipeline', 'pipelinerun', 'clustertask'].
        :param name: existing tekton object name
        :param body: patched tekton object
        :param namespace: defaults to current or default namespace
        :return: patched tekton object
        """

        utils.check_entity(entity)

        if namespace is None:
            namespace = utils.get_tekton_namespace(body)

        plural = str(entity).lower() + "s"

        try:
            return self.api_instance.patch_namespaced_custom_object(
                constants.TEKTON_GROUP,
                constants.TEKTON_VERSION,
                namespace,
                plural,
                name,
                body)
        except client.rest.ApiException as e:
            raise RuntimeError(
                "Exception when calling CustomObjectsApi->patch_namespaced_custom_object:\
                 %s\n" % e)

    def delete(self, entity, name, namespace=None):
        """
        Delete the Tekton objects
        :param entity: the tekton entity, currently supported values: ['task', 'taskrun', 'pipeline', 'pipelinerun', 'clustertask'].
        :param name: Tekton object's name
        :param namespace: defaults to current or default namespace
        :return:
        """
        utils.check_entity(entity)

        if namespace is None:
            namespace = utils.get_default_target_namespace()

        plural = str(entity).lower() + "s"

        try:
            return self.api_instance.delete_namespaced_custom_object(
                constants.TEKTON_GROUP,
                constants.TEKTON_VERSION,
                namespace,
                plural,
                name)
        except client.rest.ApiException as e:
            raise RuntimeError(
                "Exception when calling CustomObjectsApi->delete_namespaced_custom_object:\
                 %s\n" % e)



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tekton_pipeline
from tekton_pipeline.models.v1beta1_condition_check_status_fields import V1beta1ConditionCheckStatusFields  # noqa: E501
from tekton_pipeline.rest import ApiException

class TestV1beta1ConditionCheckStatusFields(unittest.TestCase):
    """V1beta1ConditionCheckStatusFields unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test V1beta1ConditionCheckStatusFields
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tekton_pipeline.models.v1beta1_condition_check_status_fields.V1beta1ConditionCheckStatusFields()  # noqa: E501
        if include_optional :
            return V1beta1ConditionCheckStatusFields(
                check = None, 
                completion_time = None, 
                pod_name = '0', 
                start_time = None
            )
        else :
            return V1beta1ConditionCheckStatusFields(
                pod_name = '0',
        )

    def testV1beta1ConditionCheckStatusFields(self):
        """Test V1beta1ConditionCheckStatusFields"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tekton_pipeline.configuration import Configuration


class V1beta1PipelineTask(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'conditions': 'list[V1beta1PipelineTaskCondition]',
        'name': 'str',
        'params': 'list[V1beta1Param]',
        'resources': 'V1beta1PipelineTaskResources',
        'retries': 'int',
        'run_after': 'list[str]',
        'task_ref': 'V1beta1TaskRef',
        'task_spec': 'V1beta1EmbeddedTask',
        'timeout': 'V1Duration',
        'when': 'list[V1beta1WhenExpression]',
        'workspaces': 'list[V1beta1WorkspacePipelineTaskBinding]'
    }

    attribute_map = {
        'conditions': 'conditions',
        'name': 'name',
        'params': 'params',
        'resources': 'resources',
        'retries': 'retries',
        'run_after': 'runAfter',
        'task_ref': 'taskRef',
        'task_spec': 'taskSpec',
        'timeout': 'timeout',
        'when': 'when',
        'workspaces': 'workspaces'
    }

    def __init__(self, conditions=None, name=None, params=None, resources=None, retries=None, run_after=None, task_ref=None, task_spec=None, timeout=None, when=None, workspaces=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1PipelineTask - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._conditions = None
        self._name = None
        self._params = None
        self._resources = None
        self._retries = None
        self._run_after = None
        self._task_ref = None
        self._task_spec = None
        self._timeout = None
        self._when = None
        self._workspaces = None
        self.discriminator = None

        if conditions is not None:
            self.conditions = conditions
        if name is not None:
            self.name = name
        if params is not None:
            self.params = params
        if resources is not None:
            self.resources = resources
        if retries is not None:
            self.retries = retries
        if run_after is not None:
            self.run_after = run_after
        if task_ref is not None:
            self.task_ref = task_ref
        if task_spec is not None:
            self.task_spec = task_spec
        if timeout is not None:
            self.timeout = timeout
        if when is not None:
            self.when = when
        if workspaces is not None:
            self.workspaces = workspaces

    @property
    def conditions(self):
        """Gets the conditions of this V1beta1PipelineTask.  # noqa: E501

        Conditions is a list of conditions that need to be true for the task to run Conditions are deprecated, use WhenExpressions instead  # noqa: E501

        :return: The conditions of this V1beta1PipelineTask.  # noqa: E501
        :rtype: list[V1beta1PipelineTaskCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this V1beta1PipelineTask.

        Conditions is a list of conditions that need to be true for the task to run Conditions are deprecated, use WhenExpressions instead  # noqa: E501

        :param conditions: The conditions of this V1beta1PipelineTask.  # noqa: E501
        :type: list[V1beta1PipelineTaskCondition]
        """

        self._conditions = conditions

    @property
    def name(self):
        """Gets the name of this V1beta1PipelineTask.  # noqa: E501

        Name is the name of this task within the context of a Pipeline. Name is used as a coordinate with the `from` and `runAfter` fields to establish the execution order of tasks relative to one another.  # noqa: E501

        :return: The name of this V1beta1PipelineTask.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1beta1PipelineTask.

        Name is the name of this task within the context of a Pipeline. Name is used as a coordinate with the `from` and `runAfter` fields to establish the execution order of tasks relative to one another.  # noqa: E501

        :param name: The name of this V1beta1PipelineTask.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def params(self):
        """Gets the params of this V1beta1PipelineTask.  # noqa: E501

        Parameters declares parameters passed to this task.  # noqa: E501

        :return: The params of this V1beta1PipelineTask.  # noqa: E501
        :rtype: list[V1beta1Param]
        """
        return self._params

    @params.setter
    def params(self, params):
        """Sets the params of this V1beta1PipelineTask.

        Parameters declares parameters passed to this task.  # noqa: E501

        :param params: The params of this V1beta1PipelineTask.  # noqa: E501
        :type: list[V1beta1Param]
        """

        self._params = params

    @property
    def resources(self):
        """Gets the resources of this V1beta1PipelineTask.  # noqa: E501


        :return: The resources of this V1beta1PipelineTask.  # noqa: E501
        :rtype: V1beta1PipelineTaskResources
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this V1beta1PipelineTask.


        :param resources: The resources of this V1beta1PipelineTask.  # noqa: E501
        :type: V1beta1PipelineTaskResources
        """

        self._resources = resources

    @property
    def retries(self):
        """Gets the retries of this V1beta1PipelineTask.  # noqa: E501

        Retries represents how many times this task should be retried in case of task failure: ConditionSucceeded set to False  # noqa: E501

        :return: The retries of this V1beta1PipelineTask.  # noqa: E501
        :rtype: int
        """
        return self._retries

    @retries.setter
    def retries(self, retries):
        """Sets the retries of this V1beta1PipelineTask.

        Retries represents how many times this task should be retried in case of task failure: ConditionSucceeded set to False  # noqa: E501

        :param retries: The retries of this V1beta1PipelineTask.  # noqa: E501
        :type: int
        """

        self._retries = retries

    @property
    def run_after(self):
        """Gets the run_after of this V1beta1PipelineTask.  # noqa: E501

        RunAfter is the list of PipelineTask names that should be executed before this Task executes. (Used to force a specific ordering in graph execution.)  # noqa: E501

        :return: The run_after of this V1beta1PipelineTask.  # noqa: E501
        :rtype: list[str]
        """
        return self._run_after

    @run_after.setter
    def run_after(self, run_after):
        """Sets the run_after of this V1beta1PipelineTask.

        RunAfter is the list of PipelineTask names that should be executed before this Task executes. (Used to force a specific ordering in graph execution.)  # noqa: E501

        :param run_after: The run_after of this V1beta1PipelineTask.  # noqa: E501
        :type: list[str]
        """

        self._run_after = run_after

    @property
    def task_ref(self):
        """Gets the task_ref of this V1beta1PipelineTask.  # noqa: E501


        :return: The task_ref of this V1beta1PipelineTask.  # noqa: E501
        :rtype: V1beta1TaskRef
        """
        return self._task_ref

    @task_ref.setter
    def task_ref(self, task_ref):
        """Sets the task_ref of this V1beta1PipelineTask.


        :param task_ref: The task_ref of this V1beta1PipelineTask.  # noqa: E501
        :type: V1beta1TaskRef
        """

        self._task_ref = task_ref

    @property
    def task_spec(self):
        """Gets the task_spec of this V1beta1PipelineTask.  # noqa: E501


        :return: The task_spec of this V1beta1PipelineTask.  # noqa: E501
        :rtype: V1beta1EmbeddedTask
        """
        return self._task_spec

    @task_spec.setter
    def task_spec(self, task_spec):
        """Sets the task_spec of this V1beta1PipelineTask.


        :param task_spec: The task_spec of this V1beta1PipelineTask.  # noqa: E501
        :type: V1beta1EmbeddedTask
        """

        self._task_spec = task_spec

    @property
    def timeout(self):
        """Gets the timeout of this V1beta1PipelineTask.  # noqa: E501


        :return: The timeout of this V1beta1PipelineTask.  # noqa: E501
        :rtype: V1Duration
        """
        return self._timeout

    @timeout.setter
    def timeout(self, timeout):
        """Sets the timeout of this V1beta1PipelineTask.


        :param timeout: The timeout of this V1beta1PipelineTask.  # noqa: E501
        :type: V1Duration
        """

        self._timeout = timeout

    @property
    def when(self):
        """Gets the when of this V1beta1PipelineTask.  # noqa: E501

        WhenExpressions is a list of when expressions that need to be true for the task to run  # noqa: E501

        :return: The when of this V1beta1PipelineTask.  # noqa: E501
        :rtype: list[V1beta1WhenExpression]
        """
        return self._when

    @when.setter
    def when(self, when):
        """Sets the when of this V1beta1PipelineTask.

        WhenExpressions is a list of when expressions that need to be true for the task to run  # noqa: E501

        :param when: The when of this V1beta1PipelineTask.  # noqa: E501
        :type: list[V1beta1WhenExpression]
        """

        self._when = when

    @property
    def workspaces(self):
        """Gets the workspaces of this V1beta1PipelineTask.  # noqa: E501

        Workspaces maps workspaces from the pipeline spec to the workspaces declared in the Task.  # noqa: E501

        :return: The workspaces of this V1beta1PipelineTask.  # noqa: E501
        :rtype: list[V1beta1WorkspacePipelineTaskBinding]
        """
        return self._workspaces

    @workspaces.setter
    def workspaces(self, workspaces):
        """Sets the workspaces of this V1beta1PipelineTask.

        Workspaces maps workspaces from the pipeline spec to the workspaces declared in the Task.  # noqa: E501

        :param workspaces: The workspaces of this V1beta1PipelineTask.  # noqa: E501
        :type: list[V1beta1WorkspacePipelineTaskBinding]
        """

        self._workspaces = workspaces

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1PipelineTask):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1PipelineTask):
            return True

        return self.to_dict() != other.to_dict()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tekton_pipeline
from tekton_pipeline.models.v1beta1_cloud_event_delivery import V1beta1CloudEventDelivery  # noqa: E501
from tekton_pipeline.rest import ApiException

class TestV1beta1CloudEventDelivery(unittest.TestCase):
    """V1beta1CloudEventDelivery unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test V1beta1CloudEventDelivery
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tekton_pipeline.models.v1beta1_cloud_event_delivery.V1beta1CloudEventDelivery()  # noqa: E501
        if include_optional :
            return V1beta1CloudEventDelivery(
                status = tekton_pipeline.models.v1beta1/cloud_event_delivery_state.v1beta1.CloudEventDeliveryState(
                    condition = '0', 
                    message = '0', 
                    retry_count = 56, 
                    sent_at = None, ), 
                target = '0'
            )
        else :
            return V1beta1CloudEventDelivery(
        )

    def testV1beta1CloudEventDelivery(self):
        """Test V1beta1CloudEventDelivery"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tekton_pipeline.configuration import Configuration


class V1beta1StepState(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'container': 'str',
        'image_id': 'str',
        'name': 'str',
        'running': 'V1ContainerStateRunning',
        'terminated': 'V1ContainerStateTerminated',
        'waiting': 'V1ContainerStateWaiting'
    }

    attribute_map = {
        'container': 'container',
        'image_id': 'imageID',
        'name': 'name',
        'running': 'running',
        'terminated': 'terminated',
        'waiting': 'waiting'
    }

    def __init__(self, container=None, image_id=None, name=None, running=None, terminated=None, waiting=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1StepState - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._container = None
        self._image_id = None
        self._name = None
        self._running = None
        self._terminated = None
        self._waiting = None
        self.discriminator = None

        if container is not None:
            self.container = container
        if image_id is not None:
            self.image_id = image_id
        if name is not None:
            self.name = name
        if running is not None:
            self.running = running
        if terminated is not None:
            self.terminated = terminated
        if waiting is not None:
            self.waiting = waiting

    @property
    def container(self):
        """Gets the container of this V1beta1StepState.  # noqa: E501


        :return: The container of this V1beta1StepState.  # noqa: E501
        :rtype: str
        """
        return self._container

    @container.setter
    def container(self, container):
        """Sets the container of this V1beta1StepState.


        :param container: The container of this V1beta1StepState.  # noqa: E501
        :type: str
        """

        self._container = container

    @property
    def image_id(self):
        """Gets the image_id of this V1beta1StepState.  # noqa: E501


        :return: The image_id of this V1beta1StepState.  # noqa: E501
        :rtype: str
        """
        return self._image_id

    @image_id.setter
    def image_id(self, image_id):
        """Sets the image_id of this V1beta1StepState.


        :param image_id: The image_id of this V1beta1StepState.  # noqa: E501
        :type: str
        """

        self._image_id = image_id

    @property
    def name(self):
        """Gets the name of this V1beta1StepState.  # noqa: E501


        :return: The name of this V1beta1StepState.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this V1beta1StepState.


        :param name: The name of this V1beta1StepState.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def running(self):
        """Gets the running of this V1beta1StepState.  # noqa: E501


        :return: The running of this V1beta1StepState.  # noqa: E501
        :rtype: V1ContainerStateRunning
        """
        return self._running

    @running.setter
    def running(self, running):
        """Sets the running of this V1beta1StepState.


        :param running: The running of this V1beta1StepState.  # noqa: E501
        :type: V1ContainerStateRunning
        """

        self._running = running

    @property
    def terminated(self):
        """Gets the terminated of this V1beta1StepState.  # noqa: E501


        :return: The terminated of this V1beta1StepState.  # noqa: E501
        :rtype: V1ContainerStateTerminated
        """
        return self._terminated

    @terminated.setter
    def terminated(self, terminated):
        """Sets the terminated of this V1beta1StepState.


        :param terminated: The terminated of this V1beta1StepState.  # noqa: E501
        :type: V1ContainerStateTerminated
        """

        self._terminated = terminated

    @property
    def waiting(self):
        """Gets the waiting of this V1beta1StepState.  # noqa: E501


        :return: The waiting of this V1beta1StepState.  # noqa: E501
        :rtype: V1ContainerStateWaiting
        """
        return self._waiting

    @waiting.setter
    def waiting(self, waiting):
        """Sets the waiting of this V1beta1StepState.


        :param waiting: The waiting of this V1beta1StepState.  # noqa: E501
        :type: V1ContainerStateWaiting
        """

        self._waiting = waiting

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1StepState):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1StepState):
            return True

        return self.to_dict() != other.to_dict()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tekton_pipeline.configuration import Configuration


class V1beta1PipelineSpec(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'description': 'str',
        '_finally': 'list[V1beta1PipelineTask]',
        'params': 'list[V1beta1ParamSpec]',
        'resources': 'list[V1beta1PipelineDeclaredResource]',
        'results': 'list[V1beta1PipelineResult]',
        'tasks': 'list[V1beta1PipelineTask]',
        'workspaces': 'list[V1beta1PipelineWorkspaceDeclaration]'
    }

    attribute_map = {
        'description': 'description',
        '_finally': 'finally',
        'params': 'params',
        'resources': 'resources',
        'results': 'results',
        'tasks': 'tasks',
        'workspaces': 'workspaces'
    }

    def __init__(self, description=None, _finally=None, params=None, resources=None, results=None, tasks=None, workspaces=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1PipelineSpec - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._description = None
        self.__finally = None
        self._params = None
        self._resources = None
        self._results = None
        self._tasks = None
        self._workspaces = None
        self.discriminator = None

        if description is not None:
            self.description = description
        if _finally is not None:
            self._finally = _finally
        if params is not None:
            self.params = params
        if resources is not None:
            self.resources = resources
        if results is not None:
            self.results = results
        if tasks is not None:
            self.tasks = tasks
        if workspaces is not None:
            self.workspaces = workspaces

    @property
    def description(self):
        """Gets the description of this V1beta1PipelineSpec.  # noqa: E501

        Description is a user-facing description of the pipeline that may be used to populate a UI.  # noqa: E501

        :return: The description of this V1beta1PipelineSpec.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this V1beta1PipelineSpec.

        Description is a user-facing description of the pipeline that may be used to populate a UI.  # noqa: E501

        :param description: The description of this V1beta1PipelineSpec.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def _finally(self):
        """Gets the _finally of this V1beta1PipelineSpec.  # noqa: E501

        Finally declares the list of Tasks that execute just before leaving the Pipeline i.e. either after all Tasks are finished executing successfully or after a failure which would result in ending the Pipeline  # noqa: E501

        :return: The _finally of this V1beta1PipelineSpec.  # noqa: E501
        :rtype: list[V1beta1PipelineTask]
        """
        return self.__finally

    @_finally.setter
    def _finally(self, _finally):
        """Sets the _finally of this V1beta1PipelineSpec.

        Finally declares the list of Tasks that execute just before leaving the Pipeline i.e. either after all Tasks are finished executing successfully or after a failure which would result in ending the Pipeline  # noqa: E501

        :param _finally: The _finally of this V1beta1PipelineSpec.  # noqa: E501
        :type: list[V1beta1PipelineTask]
        """

        self.__finally = _finally

    @property
    def params(self):
        """Gets the params of this V1beta1PipelineSpec.  # noqa: E501

        Params declares a list of input parameters that must be supplied when this Pipeline is run.  # noqa: E501

        :return: The params of this V1beta1PipelineSpec.  # noqa: E501
        :rtype: list[V1beta1ParamSpec]
        """
        return self._params

    @params.setter
    def params(self, params):
        """Sets the params of this V1beta1PipelineSpec.

        Params declares a list of input parameters that must be supplied when this Pipeline is run.  # noqa: E501

        :param params: The params of this V1beta1PipelineSpec.  # noqa: E501
        :type: list[V1beta1ParamSpec]
        """

        self._params = params

    @property
    def resources(self):
        """Gets the resources of this V1beta1PipelineSpec.  # noqa: E501

        Resources declares the names and types of the resources given to the Pipeline's tasks as inputs and outputs.  # noqa: E501

        :return: The resources of this V1beta1PipelineSpec.  # noqa: E501
        :rtype: list[V1beta1PipelineDeclaredResource]
        """
        return self._resources

    @resources.setter
    def resources(self, resources):
        """Sets the resources of this V1beta1PipelineSpec.

        Resources declares the names and types of the resources given to the Pipeline's tasks as inputs and outputs.  # noqa: E501

        :param resources: The resources of this V1beta1PipelineSpec.  # noqa: E501
        :type: list[V1beta1PipelineDeclaredResource]
        """

        self._resources = resources

    @property
    def results(self):
        """Gets the results of this V1beta1PipelineSpec.  # noqa: E501

        Results are values that this pipeline can output once run  # noqa: E501

        :return: The results of this V1beta1PipelineSpec.  # noqa: E501
        :rtype: list[V1beta1PipelineResult]
        """
        return self._results

    @results.setter
    def results(self, results):
        """Sets the results of this V1beta1PipelineSpec.

        Results are values that this pipeline can output once run  # noqa: E501

        :param results: The results of this V1beta1PipelineSpec.  # noqa: E501
        :type: list[V1beta1PipelineResult]
        """

        self._results = results

    @property
    def tasks(self):
        """Gets the tasks of this V1beta1PipelineSpec.  # noqa: E501

        Tasks declares the graph of Tasks that execute when this Pipeline is run.  # noqa: E501

        :return: The tasks of this V1beta1PipelineSpec.  # noqa: E501
        :rtype: list[V1beta1PipelineTask]
        """
        return self._tasks

    @tasks.setter
    def tasks(self, tasks):
        """Sets the tasks of this V1beta1PipelineSpec.

        Tasks declares the graph of Tasks that execute when this Pipeline is run.  # noqa: E501

        :param tasks: The tasks of this V1beta1PipelineSpec.  # noqa: E501
        :type: list[V1beta1PipelineTask]
        """

        self._tasks = tasks

    @property
    def workspaces(self):
        """Gets the workspaces of this V1beta1PipelineSpec.  # noqa: E501

        Workspaces declares a set of named workspaces that are expected to be provided by a PipelineRun.  # noqa: E501

        :return: The workspaces of this V1beta1PipelineSpec.  # noqa: E501
        :rtype: list[V1beta1PipelineWorkspaceDeclaration]
        """
        return self._workspaces

    @workspaces.setter
    def workspaces(self, workspaces):
        """Sets the workspaces of this V1beta1PipelineSpec.

        Workspaces declares a set of named workspaces that are expected to be provided by a PipelineRun.  # noqa: E501

        :param workspaces: The workspaces of this V1beta1PipelineSpec.  # noqa: E501
        :type: list[V1beta1PipelineWorkspaceDeclaration]
        """

        self._workspaces = workspaces

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1PipelineSpec):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1PipelineSpec):
            return True

        return self.to_dict() != other.to_dict()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tekton_pipeline
from tekton_pipeline.models.v1beta1_task_run_list import V1beta1TaskRunList  # noqa: E501
from tekton_pipeline.rest import ApiException

class TestV1beta1TaskRunList(unittest.TestCase):
    """V1beta1TaskRunList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test V1beta1TaskRunList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tekton_pipeline.models.v1beta1_task_run_list.V1beta1TaskRunList()  # noqa: E501
        if include_optional :
            return V1beta1TaskRunList(
                api_version = '0', 
                items = [
                    tekton_pipeline.models.v1beta1/task_run.v1beta1.TaskRun(
                        api_version = '0', 
                        kind = '0', 
                        metadata = None, 
                        spec = tekton_pipeline.models.v1beta1/task_run_spec.v1beta1.TaskRunSpec(
                            params = [
                                tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                                    name = '0', 
                                    value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                        array_val = [
                                            '0'
                                            ], 
                                        string_val = '0', 
                                        type = '0', ), )
                                ], 
                            pod_template = tekton_pipeline.models.pod/template.pod.Template(
                                affinity = None, 
                                automount_service_account_token = True, 
                                dns_config = None, 
                                dns_policy = '0', 
                                enable_service_links = True, 
                                host_network = True, 
                                image_pull_secrets = [
                                    None
                                    ], 
                                node_selector = {
                                    'key' : '0'
                                    }, 
                                priority_class_name = '0', 
                                runtime_class_name = '0', 
                                scheduler_name = '0', 
                                security_context = None, 
                                tolerations = [
                                    None
                                    ], 
                                volumes = [
                                    None
                                    ], ), 
                            resources = tekton_pipeline.models.v1beta1/task_run_resources.v1beta1.TaskRunResources(
                                inputs = [
                                    tekton_pipeline.models.v1beta1/task_resource_binding.v1beta1.TaskResourceBinding(
                                        name = '0', 
                                        paths = [
                                            '0'
                                            ], 
                                        resource_ref = tekton_pipeline.models.v1beta1/pipeline_resource_ref.v1beta1.PipelineResourceRef(
                                            api_version = '0', 
                                            name = '0', ), 
                                        resource_spec = tekton_pipeline.models.v1alpha1/pipeline_resource_spec.v1alpha1.PipelineResourceSpec(
                                            description = '0', 
                                            params = [
                                                tekton_pipeline.models.v1alpha1/resource_param.v1alpha1.ResourceParam(
                                                    name = '0', 
                                                    value = '0', )
                                                ], 
                                            secrets = [
                                                tekton_pipeline.models.v1alpha1/secret_param.v1alpha1.SecretParam(
                                                    field_name = '0', 
                                                    secret_key = '0', 
                                                    secret_name = '0', )
                                                ], 
                                            type = '0', ), )
                                    ], 
                                outputs = [
                                    tekton_pipeline.models.v1beta1/task_resource_binding.v1beta1.TaskResourceBinding(
                                        name = '0', )
                                    ], ), 
                            service_account_name = '0', 
                            status = '0', 
                            task_ref = tekton_pipeline.models.v1beta1/task_ref.v1beta1.TaskRef(
                                api_version = '0', 
                                bundle = '0', 
                                kind = '0', 
                                name = '0', ), 
                            task_spec = tekton_pipeline.models.v1beta1/task_spec.v1beta1.TaskSpec(
                                description = '0', 
                                results = [
                                    tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                        description = '0', 
                                        name = '0', )
                                    ], 
                                sidecars = [
                                    tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                                        args = [
                                            '0'
                                            ], 
                                        command = [
                                            '0'
                                            ], 
                                        env = [
                                            None
                                            ], 
                                        env_from = [
                                            None
                                            ], 
                                        image = '0', 
                                        image_pull_policy = '0', 
                                        lifecycle = None, 
                                        liveness_probe = None, 
                                        name = '0', 
                                        ports = [
                                            None
                                            ], 
                                        readiness_probe = None, 
                                        script = '0', 
                                        security_context = None, 
                                        startup_probe = None, 
                                        stdin = True, 
                                        stdin_once = True, 
                                        termination_message_path = '0', 
                                        termination_message_policy = '0', 
                                        tty = True, 
                                        volume_devices = [
                                            None
                                            ], 
                                        volume_mounts = [
                                            None
                                            ], 
                                        working_dir = '0', )
                                    ], 
                                step_template = None, 
                                steps = [
                                    tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                                        image = '0', 
                                        image_pull_policy = '0', 
                                        lifecycle = None, 
                                        liveness_probe = None, 
                                        name = '0', 
                                        readiness_probe = None, 
                                        script = '0', 
                                        security_context = None, 
                                        startup_probe = None, 
                                        stdin = True, 
                                        stdin_once = True, 
                                        termination_message_path = '0', 
                                        termination_message_policy = '0', 
                                        timeout = None, 
                                        tty = True, 
                                        working_dir = '0', )
                                    ], 
                                workspaces = [
                                    tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                        description = '0', 
                                        mount_path = '0', 
                                        name = '0', 
                                        optional = True, 
                                        read_only = True, )
                                    ], ), 
                            timeout = None, 
                            workspaces = [
                                tekton_pipeline.models.v1beta1/workspace_binding.v1beta1.WorkspaceBinding(
                                    config_map = None, 
                                    empty_dir = None, 
                                    name = '0', 
                                    persistent_volume_claim = None, 
                                    secret = None, 
                                    sub_path = '0', 
                                    volume_claim_template = None, )
                                ], ), 
                        status = tekton_pipeline.models.v1beta1/task_run_status.v1beta1.TaskRunStatus(
                            annotations = {
                                'key' : '0'
                                }, 
                            cloud_events = [
                                tekton_pipeline.models.v1beta1/cloud_event_delivery.v1beta1.CloudEventDelivery(
                                    target = '0', )
                                ], 
                            completion_time = None, 
                            conditions = [
                                None
                                ], 
                            observed_generation = 56, 
                            pod_name = '0', 
                            resources_result = [
                                tekton_pipeline.models.v1beta1/pipeline_resource_result.v1beta1.PipelineResourceResult(
                                    key = '0', 
                                    resource_name = '0', 
                                    type = '0', 
                                    value = '0', )
                                ], 
                            retries_status = [
                                tekton_pipeline.models.v1beta1/task_run_status.v1beta1.TaskRunStatus(
                                    completion_time = None, 
                                    observed_generation = 56, 
                                    pod_name = '0', 
                                    start_time = None, 
                                    task_results = [
                                        tekton_pipeline.models.v1beta1/task_run_result.v1beta1.TaskRunResult(
                                            name = '0', 
                                            value = '0', )
                                        ], )
                                ], 
                            start_time = None, 
                            task_results = [
                                tekton_pipeline.models.v1beta1/task_run_result.v1beta1.TaskRunResult(
                                    name = '0', 
                                    value = '0', )
                                ], ), )
                    ], 
                kind = '0', 
                metadata = None
            )
        else :
            return V1beta1TaskRunList(
                items = [
                    tekton_pipeline.models.v1beta1/task_run.v1beta1.TaskRun(
                        api_version = '0', 
                        kind = '0', 
                        metadata = None, 
                        spec = tekton_pipeline.models.v1beta1/task_run_spec.v1beta1.TaskRunSpec(
                            params = [
                                tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                                    name = '0', 
                                    value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                        array_val = [
                                            '0'
                                            ], 
                                        string_val = '0', 
                                        type = '0', ), )
                                ], 
                            pod_template = tekton_pipeline.models.pod/template.pod.Template(
                                affinity = None, 
                                automount_service_account_token = True, 
                                dns_config = None, 
                                dns_policy = '0', 
                                enable_service_links = True, 
                                host_network = True, 
                                image_pull_secrets = [
                                    None
                                    ], 
                                node_selector = {
                                    'key' : '0'
                                    }, 
                                priority_class_name = '0', 
                                runtime_class_name = '0', 
                                scheduler_name = '0', 
                                security_context = None, 
                                tolerations = [
                                    None
                                    ], 
                                volumes = [
                                    None
                                    ], ), 
                            resources = tekton_pipeline.models.v1beta1/task_run_resources.v1beta1.TaskRunResources(
                                inputs = [
                                    tekton_pipeline.models.v1beta1/task_resource_binding.v1beta1.TaskResourceBinding(
                                        name = '0', 
                                        paths = [
                                            '0'
                                            ], 
                                        resource_ref = tekton_pipeline.models.v1beta1/pipeline_resource_ref.v1beta1.PipelineResourceRef(
                                            api_version = '0', 
                                            name = '0', ), 
                                        resource_spec = tekton_pipeline.models.v1alpha1/pipeline_resource_spec.v1alpha1.PipelineResourceSpec(
                                            description = '0', 
                                            params = [
                                                tekton_pipeline.models.v1alpha1/resource_param.v1alpha1.ResourceParam(
                                                    name = '0', 
                                                    value = '0', )
                                                ], 
                                            secrets = [
                                                tekton_pipeline.models.v1alpha1/secret_param.v1alpha1.SecretParam(
                                                    field_name = '0', 
                                                    secret_key = '0', 
                                                    secret_name = '0', )
                                                ], 
                                            type = '0', ), )
                                    ], 
                                outputs = [
                                    tekton_pipeline.models.v1beta1/task_resource_binding.v1beta1.TaskResourceBinding(
                                        name = '0', )
                                    ], ), 
                            service_account_name = '0', 
                            status = '0', 
                            task_ref = tekton_pipeline.models.v1beta1/task_ref.v1beta1.TaskRef(
                                api_version = '0', 
                                bundle = '0', 
                                kind = '0', 
                                name = '0', ), 
                            task_spec = tekton_pipeline.models.v1beta1/task_spec.v1beta1.TaskSpec(
                                description = '0', 
                                results = [
                                    tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                        description = '0', 
                                        name = '0', )
                                    ], 
                                sidecars = [
                                    tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                                        args = [
                                            '0'
                                            ], 
                                        command = [
                                            '0'
                                            ], 
                                        env = [
                                            None
                                            ], 
                                        env_from = [
                                            None
                                            ], 
                                        image = '0', 
                                        image_pull_policy = '0', 
                                        lifecycle = None, 
                                        liveness_probe = None, 
                                        name = '0', 
                                        ports = [
                                            None
                                            ], 
                                        readiness_probe = None, 
                                        script = '0', 
                                        security_context = None, 
                                        startup_probe = None, 
                                        stdin = True, 
                                        stdin_once = True, 
                                        termination_message_path = '0', 
                                        termination_message_policy = '0', 
                                        tty = True, 
                                        volume_devices = [
                                            None
                                            ], 
                                        volume_mounts = [
                                            None
                                            ], 
                                        working_dir = '0', )
                                    ], 
                                step_template = None, 
                                steps = [
                                    tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                                        image = '0', 
                                        image_pull_policy = '0', 
                                        lifecycle = None, 
                                        liveness_probe = None, 
                                        name = '0', 
                                        readiness_probe = None, 
                                        script = '0', 
                                        security_context = None, 
                                        startup_probe = None, 
                                        stdin = True, 
                                        stdin_once = True, 
                                        termination_message_path = '0', 
                                        termination_message_policy = '0', 
                                        timeout = None, 
                                        tty = True, 
                                        working_dir = '0', )
                                    ], 
                                workspaces = [
                                    tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                        description = '0', 
                                        mount_path = '0', 
                                        name = '0', 
                                        optional = True, 
                                        read_only = True, )
                                    ], ), 
                            timeout = None, 
                            workspaces = [
                                tekton_pipeline.models.v1beta1/workspace_binding.v1beta1.WorkspaceBinding(
                                    config_map = None, 
                                    empty_dir = None, 
                                    name = '0', 
                                    persistent_volume_claim = None, 
                                    secret = None, 
                                    sub_path = '0', 
                                    volume_claim_template = None, )
                                ], ), 
                        status = tekton_pipeline.models.v1beta1/task_run_status.v1beta1.TaskRunStatus(
                            annotations = {
                                'key' : '0'
                                }, 
                            cloud_events = [
                                tekton_pipeline.models.v1beta1/cloud_event_delivery.v1beta1.CloudEventDelivery(
                                    target = '0', )
                                ], 
                            completion_time = None, 
                            conditions = [
                                None
                                ], 
                            observed_generation = 56, 
                            pod_name = '0', 
                            resources_result = [
                                tekton_pipeline.models.v1beta1/pipeline_resource_result.v1beta1.PipelineResourceResult(
                                    key = '0', 
                                    resource_name = '0', 
                                    type = '0', 
                                    value = '0', )
                                ], 
                            retries_status = [
                                tekton_pipeline.models.v1beta1/task_run_status.v1beta1.TaskRunStatus(
                                    completion_time = None, 
                                    observed_generation = 56, 
                                    pod_name = '0', 
                                    start_time = None, 
                                    task_results = [
                                        tekton_pipeline.models.v1beta1/task_run_result.v1beta1.TaskRunResult(
                                            name = '0', 
                                            value = '0', )
                                        ], )
                                ], 
                            start_time = None, 
                            task_results = [
                                tekton_pipeline.models.v1beta1/task_run_result.v1beta1.TaskRunResult(
                                    name = '0', 
                                    value = '0', )
                                ], ), )
                    ],
        )

    def testV1beta1TaskRunList(self):
        """Test V1beta1TaskRunList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tekton_pipeline
from tekton_pipeline.models.v1beta1_condition_check import V1beta1ConditionCheck  # noqa: E501
from tekton_pipeline.rest import ApiException

class TestV1beta1ConditionCheck(unittest.TestCase):
    """V1beta1ConditionCheck unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test V1beta1ConditionCheck
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tekton_pipeline.models.v1beta1_condition_check.V1beta1ConditionCheck()  # noqa: E501
        if include_optional :
            return V1beta1ConditionCheck(
                api_version = '0', 
                kind = '0', 
                metadata = None, 
                spec = tekton_pipeline.models.v1beta1/task_run_spec.v1beta1.TaskRunSpec(
                    params = [
                        tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                            name = '0', 
                            value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                array_val = [
                                    '0'
                                    ], 
                                string_val = '0', 
                                type = '0', ), )
                        ], 
                    pod_template = tekton_pipeline.models.pod/template.pod.Template(
                        affinity = None, 
                        automount_service_account_token = True, 
                        dns_config = None, 
                        dns_policy = '0', 
                        enable_service_links = True, 
                        host_network = True, 
                        image_pull_secrets = [
                            None
                            ], 
                        node_selector = {
                            'key' : '0'
                            }, 
                        priority_class_name = '0', 
                        runtime_class_name = '0', 
                        scheduler_name = '0', 
                        security_context = None, 
                        tolerations = [
                            None
                            ], 
                        volumes = [
                            None
                            ], ), 
                    resources = tekton_pipeline.models.v1beta1/task_run_resources.v1beta1.TaskRunResources(
                        inputs = [
                            tekton_pipeline.models.v1beta1/task_resource_binding.v1beta1.TaskResourceBinding(
                                name = '0', 
                                paths = [
                                    '0'
                                    ], 
                                resource_ref = tekton_pipeline.models.v1beta1/pipeline_resource_ref.v1beta1.PipelineResourceRef(
                                    api_version = '0', 
                                    name = '0', ), 
                                resource_spec = tekton_pipeline.models.v1alpha1/pipeline_resource_spec.v1alpha1.PipelineResourceSpec(
                                    description = '0', 
                                    params = [
                                        tekton_pipeline.models.v1alpha1/resource_param.v1alpha1.ResourceParam(
                                            name = '0', 
                                            value = '0', )
                                        ], 
                                    secrets = [
                                        tekton_pipeline.models.v1alpha1/secret_param.v1alpha1.SecretParam(
                                            field_name = '0', 
                                            secret_key = '0', 
                                            secret_name = '0', )
                                        ], 
                                    type = '0', ), )
                            ], 
                        outputs = [
                            tekton_pipeline.models.v1beta1/task_resource_binding.v1beta1.TaskResourceBinding(
                                name = '0', )
                            ], ), 
                    service_account_name = '0', 
                    status = '0', 
                    task_ref = tekton_pipeline.models.v1beta1/task_ref.v1beta1.TaskRef(
                        api_version = '0', 
                        bundle = '0', 
                        kind = '0', 
                        name = '0', ), 
                    task_spec = tekton_pipeline.models.v1beta1/task_spec.v1beta1.TaskSpec(
                        description = '0', 
                        results = [
                            tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                description = '0', 
                                name = '0', )
                            ], 
                        sidecars = [
                            tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                                args = [
                                    '0'
                                    ], 
                                command = [
                                    '0'
                                    ], 
                                env = [
                                    None
                                    ], 
                                env_from = [
                                    None
                                    ], 
                                image = '0', 
                                image_pull_policy = '0', 
                                lifecycle = None, 
                                liveness_probe = None, 
                                name = '0', 
                                ports = [
                                    None
                                    ], 
                                readiness_probe = None, 
                                script = '0', 
                                security_context = None, 
                                startup_probe = None, 
                                stdin = True, 
                                stdin_once = True, 
                                termination_message_path = '0', 
                                termination_message_policy = '0', 
                                tty = True, 
                                volume_devices = [
                                    None
                                    ], 
                                volume_mounts = [
                                    None
                                    ], 
                                working_dir = '0', )
                            ], 
                        step_template = None, 
                        steps = [
                            tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                                image = '0', 
                                image_pull_policy = '0', 
                                lifecycle = None, 
                                liveness_probe = None, 
                                name = '0', 
                                readiness_probe = None, 
                                script = '0', 
                                security_context = None, 
                                startup_probe = None, 
                                stdin = True, 
                                stdin_once = True, 
                                termination_message_path = '0', 
                                termination_message_policy = '0', 
                                timeout = None, 
                                tty = True, 
                                working_dir = '0', )
                            ], 
                        workspaces = [
                            tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                description = '0', 
                                mount_path = '0', 
                                name = '0', 
                                optional = True, 
                                read_only = True, )
                            ], ), 
                    timeout = None, 
                    workspaces = [
                        tekton_pipeline.models.v1beta1/workspace_binding.v1beta1.WorkspaceBinding(
                            config_map = None, 
                            empty_dir = None, 
                            name = '0', 
                            persistent_volume_claim = None, 
                            secret = None, 
                            sub_path = '0', 
                            volume_claim_template = None, )
                        ], ), 
                status = tekton_pipeline.models.v1beta1/task_run_status.v1beta1.TaskRunStatus(
                    annotations = {
                        'key' : '0'
                        }, 
                    cloud_events = [
                        tekton_pipeline.models.v1beta1/cloud_event_delivery.v1beta1.CloudEventDelivery(
                            status = tekton_pipeline.models.v1beta1/cloud_event_delivery_state.v1beta1.CloudEventDeliveryState(
                                condition = '0', 
                                message = '0', 
                                retry_count = 56, 
                                sent_at = None, ), 
                            target = '0', )
                        ], 
                    completion_time = None, 
                    conditions = [
                        None
                        ], 
                    observed_generation = 56, 
                    pod_name = '0', 
                    resources_result = [
                        tekton_pipeline.models.v1beta1/pipeline_resource_result.v1beta1.PipelineResourceResult(
                            key = '0', 
                            resource_name = '0', 
                            resource_ref = tekton_pipeline.models.v1beta1/pipeline_resource_ref.v1beta1.PipelineResourceRef(
                                api_version = '0', 
                                name = '0', ), 
                            type = '0', 
                            value = '0', )
                        ], 
                    retries_status = [
                        tekton_pipeline.models.v1beta1/task_run_status.v1beta1.TaskRunStatus(
                            completion_time = None, 
                            observed_generation = 56, 
                            pod_name = '0', 
                            sidecars = [
                                tekton_pipeline.models.v1beta1/sidecar_state.v1beta1.SidecarState(
                                    container = '0', 
                                    image_id = '0', 
                                    name = '0', 
                                    running = None, 
                                    terminated = None, 
                                    waiting = None, )
                                ], 
                            start_time = None, 
                            steps = [
                                tekton_pipeline.models.v1beta1/step_state.v1beta1.StepState(
                                    container = '0', 
                                    image_id = '0', 
                                    name = '0', 
                                    running = None, 
                                    terminated = None, 
                                    waiting = None, )
                                ], 
                            task_results = [
                                tekton_pipeline.models.v1beta1/task_run_result.v1beta1.TaskRunResult(
                                    name = '0', 
                                    value = '0', )
                                ], 
                            task_spec = tekton_pipeline.models.v1beta1/task_spec.v1beta1.TaskSpec(
                                description = '0', 
                                params = [
                                    tekton_pipeline.models.v1beta1/param_spec.v1beta1.ParamSpec(
                                        default = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                            array_val = [
                                                '0'
                                                ], 
                                            string_val = '0', 
                                            type = '0', ), 
                                        description = '0', 
                                        name = '0', 
                                        type = '0', )
                                    ], 
                                resources = tekton_pipeline.models.v1beta1/task_resources.v1beta1.TaskResources(
                                    inputs = [
                                        tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                                            description = '0', 
                                            name = '0', 
                                            optional = True, 
                                            target_path = '0', 
                                            type = '0', )
                                        ], 
                                    outputs = [
                                        tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                                            description = '0', 
                                            name = '0', 
                                            optional = True, 
                                            target_path = '0', 
                                            type = '0', )
                                        ], ), 
                                results = [
                                    tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                        description = '0', 
                                        name = '0', )
                                    ], 
                                step_template = None, 
                                volumes = [
                                    None
                                    ], 
                                workspaces = [
                                    tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                        description = '0', 
                                        mount_path = '0', 
                                        name = '0', 
                                        optional = True, 
                                        read_only = True, )
                                    ], ), )
                        ], 
                    sidecars = [
                        tekton_pipeline.models.v1beta1/sidecar_state.v1beta1.SidecarState(
                            container = '0', 
                            image_id = '0', 
                            name = '0', 
                            running = None, 
                            terminated = None, 
                            waiting = None, )
                        ], 
                    start_time = None, 
                    steps = [
                        tekton_pipeline.models.v1beta1/step_state.v1beta1.StepState(
                            container = '0', 
                            image_id = '0', 
                            name = '0', 
                            running = None, 
                            terminated = None, 
                            waiting = None, )
                        ], 
                    task_results = [
                        tekton_pipeline.models.v1beta1/task_run_result.v1beta1.TaskRunResult(
                            name = '0', 
                            value = '0', )
                        ], 
                    task_spec = tekton_pipeline.models.v1beta1/task_spec.v1beta1.TaskSpec(
                        description = '0', 
                        step_template = None, ), )
            )
        else :
            return V1beta1ConditionCheck(
        )

    def testV1beta1ConditionCheck(self):
        """Test V1beta1ConditionCheck"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tekton_pipeline
from tekton_pipeline.models.v1beta1_cluster_task_list import V1beta1ClusterTaskList  # noqa: E501
from tekton_pipeline.rest import ApiException

class TestV1beta1ClusterTaskList(unittest.TestCase):
    """V1beta1ClusterTaskList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test V1beta1ClusterTaskList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tekton_pipeline.models.v1beta1_cluster_task_list.V1beta1ClusterTaskList()  # noqa: E501
        if include_optional :
            return V1beta1ClusterTaskList(
                api_version = '0', 
                items = [
                    tekton_pipeline.models.v1beta1/cluster_task.v1beta1.ClusterTask(
                        api_version = '0', 
                        kind = '0', 
                        metadata = None, 
                        spec = tekton_pipeline.models.v1beta1/task_spec.v1beta1.TaskSpec(
                            description = '0', 
                            params = [
                                tekton_pipeline.models.v1beta1/param_spec.v1beta1.ParamSpec(
                                    default = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                        array_val = [
                                            '0'
                                            ], 
                                        string_val = '0', 
                                        type = '0', ), 
                                    description = '0', 
                                    name = '0', 
                                    type = '0', )
                                ], 
                            resources = tekton_pipeline.models.v1beta1/task_resources.v1beta1.TaskResources(
                                inputs = [
                                    tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                                        description = '0', 
                                        name = '0', 
                                        optional = True, 
                                        target_path = '0', 
                                        type = '0', )
                                    ], 
                                outputs = [
                                    tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                                        description = '0', 
                                        name = '0', 
                                        optional = True, 
                                        target_path = '0', 
                                        type = '0', )
                                    ], ), 
                            results = [
                                tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                    description = '0', 
                                    name = '0', )
                                ], 
                            sidecars = [
                                tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                                    args = [
                                        '0'
                                        ], 
                                    command = [
                                        '0'
                                        ], 
                                    env = [
                                        None
                                        ], 
                                    env_from = [
                                        None
                                        ], 
                                    image = '0', 
                                    image_pull_policy = '0', 
                                    lifecycle = None, 
                                    liveness_probe = None, 
                                    name = '0', 
                                    ports = [
                                        None
                                        ], 
                                    readiness_probe = None, 
                                    script = '0', 
                                    security_context = None, 
                                    startup_probe = None, 
                                    stdin = True, 
                                    stdin_once = True, 
                                    termination_message_path = '0', 
                                    termination_message_policy = '0', 
                                    tty = True, 
                                    volume_devices = [
                                        None
                                        ], 
                                    volume_mounts = [
                                        None
                                        ], 
                                    working_dir = '0', )
                                ], 
                            step_template = None, 
                            steps = [
                                tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                                    image = '0', 
                                    image_pull_policy = '0', 
                                    lifecycle = None, 
                                    liveness_probe = None, 
                                    name = '0', 
                                    readiness_probe = None, 
                                    script = '0', 
                                    security_context = None, 
                                    startup_probe = None, 
                                    stdin = True, 
                                    stdin_once = True, 
                                    termination_message_path = '0', 
                                    termination_message_policy = '0', 
                                    timeout = None, 
                                    tty = True, 
                                    working_dir = '0', )
                                ], 
                            volumes = [
                                None
                                ], 
                            workspaces = [
                                tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                    description = '0', 
                                    mount_path = '0', 
                                    name = '0', 
                                    optional = True, 
                                    read_only = True, )
                                ], ), )
                    ], 
                kind = '0', 
                metadata = None
            )
        else :
            return V1beta1ClusterTaskList(
                items = [
                    tekton_pipeline.models.v1beta1/cluster_task.v1beta1.ClusterTask(
                        api_version = '0', 
                        kind = '0', 
                        metadata = None, 
                        spec = tekton_pipeline.models.v1beta1/task_spec.v1beta1.TaskSpec(
                            description = '0', 
                            params = [
                                tekton_pipeline.models.v1beta1/param_spec.v1beta1.ParamSpec(
                                    default = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                        array_val = [
                                            '0'
                                            ], 
                                        string_val = '0', 
                                        type = '0', ), 
                                    description = '0', 
                                    name = '0', 
                                    type = '0', )
                                ], 
                            resources = tekton_pipeline.models.v1beta1/task_resources.v1beta1.TaskResources(
                                inputs = [
                                    tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                                        description = '0', 
                                        name = '0', 
                                        optional = True, 
                                        target_path = '0', 
                                        type = '0', )
                                    ], 
                                outputs = [
                                    tekton_pipeline.models.v1beta1/task_resource.v1beta1.TaskResource(
                                        description = '0', 
                                        name = '0', 
                                        optional = True, 
                                        target_path = '0', 
                                        type = '0', )
                                    ], ), 
                            results = [
                                tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                    description = '0', 
                                    name = '0', )
                                ], 
                            sidecars = [
                                tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                                    args = [
                                        '0'
                                        ], 
                                    command = [
                                        '0'
                                        ], 
                                    env = [
                                        None
                                        ], 
                                    env_from = [
                                        None
                                        ], 
                                    image = '0', 
                                    image_pull_policy = '0', 
                                    lifecycle = None, 
                                    liveness_probe = None, 
                                    name = '0', 
                                    ports = [
                                        None
                                        ], 
                                    readiness_probe = None, 
                                    script = '0', 
                                    security_context = None, 
                                    startup_probe = None, 
                                    stdin = True, 
                                    stdin_once = True, 
                                    termination_message_path = '0', 
                                    termination_message_policy = '0', 
                                    tty = True, 
                                    volume_devices = [
                                        None
                                        ], 
                                    volume_mounts = [
                                        None
                                        ], 
                                    working_dir = '0', )
                                ], 
                            step_template = None, 
                            steps = [
                                tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                                    image = '0', 
                                    image_pull_policy = '0', 
                                    lifecycle = None, 
                                    liveness_probe = None, 
                                    name = '0', 
                                    readiness_probe = None, 
                                    script = '0', 
                                    security_context = None, 
                                    startup_probe = None, 
                                    stdin = True, 
                                    stdin_once = True, 
                                    termination_message_path = '0', 
                                    termination_message_policy = '0', 
                                    timeout = None, 
                                    tty = True, 
                                    working_dir = '0', )
                                ], 
                            volumes = [
                                None
                                ], 
                            workspaces = [
                                tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                    description = '0', 
                                    mount_path = '0', 
                                    name = '0', 
                                    optional = True, 
                                    read_only = True, )
                                ], ), )
                    ],
        )

    def testV1beta1ClusterTaskList(self):
        """Test V1beta1ClusterTaskList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import os


def is_running_in_k8s():
    return os.path.isdir('/var/run/secrets/kubernetes.io/')


def get_current_k8s_namespace():
    with open('/var/run/secrets/kubernetes.io/serviceaccount/namespace', 'r') as f:
        return f.readline()


def get_default_target_namespace():
    if not is_running_in_k8s():
        return 'default'
    return get_current_k8s_namespace()


def get_tekton_namespace(tekton):
    tekton_namespace = tekton.metadata.namespace
    namespace = tekton_namespace or get_default_target_namespace()
    return namespace


def get_tekton_plural(tekton):
    tekton_plural = str(tekton.kind).lower() + "s"
    return tekton_plural

def check_entity(entity):
    valid_entities = ['task', 'taskrun', 'pipeline', 'pipelinerun']
    if entity not in valid_entities:
        raise RuntimeError("The entity %s is not support, currently supported entities: %s" %
                           (entity, valid_entities))



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from tekton_pipeline.configuration import Configuration


class V1beta1ConditionCheckStatus(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'annotations': 'dict(str, str)',
        'check': 'V1ContainerState',
        'completion_time': 'V1Time',
        'conditions': 'list[KnativeCondition]',
        'observed_generation': 'int',
        'pod_name': 'str',
        'start_time': 'V1Time'
    }

    attribute_map = {
        'annotations': 'annotations',
        'check': 'check',
        'completion_time': 'completionTime',
        'conditions': 'conditions',
        'observed_generation': 'observedGeneration',
        'pod_name': 'podName',
        'start_time': 'startTime'
    }

    def __init__(self, annotations=None, check=None, completion_time=None, conditions=None, observed_generation=None, pod_name=None, start_time=None, local_vars_configuration=None):  # noqa: E501
        """V1beta1ConditionCheckStatus - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._annotations = None
        self._check = None
        self._completion_time = None
        self._conditions = None
        self._observed_generation = None
        self._pod_name = None
        self._start_time = None
        self.discriminator = None

        if annotations is not None:
            self.annotations = annotations
        if check is not None:
            self.check = check
        if completion_time is not None:
            self.completion_time = completion_time
        if conditions is not None:
            self.conditions = conditions
        if observed_generation is not None:
            self.observed_generation = observed_generation
        self.pod_name = pod_name
        if start_time is not None:
            self.start_time = start_time

    @property
    def annotations(self):
        """Gets the annotations of this V1beta1ConditionCheckStatus.  # noqa: E501

        Annotations is additional Status fields for the Resource to save some additional State as well as convey more information to the user. This is roughly akin to Annotations on any k8s resource, just the reconciler conveying richer information outwards.  # noqa: E501

        :return: The annotations of this V1beta1ConditionCheckStatus.  # noqa: E501
        :rtype: dict(str, str)
        """
        return self._annotations

    @annotations.setter
    def annotations(self, annotations):
        """Sets the annotations of this V1beta1ConditionCheckStatus.

        Annotations is additional Status fields for the Resource to save some additional State as well as convey more information to the user. This is roughly akin to Annotations on any k8s resource, just the reconciler conveying richer information outwards.  # noqa: E501

        :param annotations: The annotations of this V1beta1ConditionCheckStatus.  # noqa: E501
        :type: dict(str, str)
        """

        self._annotations = annotations

    @property
    def check(self):
        """Gets the check of this V1beta1ConditionCheckStatus.  # noqa: E501


        :return: The check of this V1beta1ConditionCheckStatus.  # noqa: E501
        :rtype: V1ContainerState
        """
        return self._check

    @check.setter
    def check(self, check):
        """Sets the check of this V1beta1ConditionCheckStatus.


        :param check: The check of this V1beta1ConditionCheckStatus.  # noqa: E501
        :type: V1ContainerState
        """

        self._check = check

    @property
    def completion_time(self):
        """Gets the completion_time of this V1beta1ConditionCheckStatus.  # noqa: E501


        :return: The completion_time of this V1beta1ConditionCheckStatus.  # noqa: E501
        :rtype: V1Time
        """
        return self._completion_time

    @completion_time.setter
    def completion_time(self, completion_time):
        """Sets the completion_time of this V1beta1ConditionCheckStatus.


        :param completion_time: The completion_time of this V1beta1ConditionCheckStatus.  # noqa: E501
        :type: V1Time
        """

        self._completion_time = completion_time

    @property
    def conditions(self):
        """Gets the conditions of this V1beta1ConditionCheckStatus.  # noqa: E501

        Conditions the latest available observations of a resource's current state.  # noqa: E501

        :return: The conditions of this V1beta1ConditionCheckStatus.  # noqa: E501
        :rtype: list[KnativeCondition]
        """
        return self._conditions

    @conditions.setter
    def conditions(self, conditions):
        """Sets the conditions of this V1beta1ConditionCheckStatus.

        Conditions the latest available observations of a resource's current state.  # noqa: E501

        :param conditions: The conditions of this V1beta1ConditionCheckStatus.  # noqa: E501
        :type: list[KnativeCondition]
        """

        self._conditions = conditions

    @property
    def observed_generation(self):
        """Gets the observed_generation of this V1beta1ConditionCheckStatus.  # noqa: E501

        ObservedGeneration is the 'Generation' of the Service that was last processed by the controller.  # noqa: E501

        :return: The observed_generation of this V1beta1ConditionCheckStatus.  # noqa: E501
        :rtype: int
        """
        return self._observed_generation

    @observed_generation.setter
    def observed_generation(self, observed_generation):
        """Sets the observed_generation of this V1beta1ConditionCheckStatus.

        ObservedGeneration is the 'Generation' of the Service that was last processed by the controller.  # noqa: E501

        :param observed_generation: The observed_generation of this V1beta1ConditionCheckStatus.  # noqa: E501
        :type: int
        """

        self._observed_generation = observed_generation

    @property
    def pod_name(self):
        """Gets the pod_name of this V1beta1ConditionCheckStatus.  # noqa: E501

        PodName is the name of the pod responsible for executing this condition check.  # noqa: E501

        :return: The pod_name of this V1beta1ConditionCheckStatus.  # noqa: E501
        :rtype: str
        """
        return self._pod_name

    @pod_name.setter
    def pod_name(self, pod_name):
        """Sets the pod_name of this V1beta1ConditionCheckStatus.

        PodName is the name of the pod responsible for executing this condition check.  # noqa: E501

        :param pod_name: The pod_name of this V1beta1ConditionCheckStatus.  # noqa: E501
        :type: str
        """
        if self.local_vars_configuration.client_side_validation and pod_name is None:  # noqa: E501
            raise ValueError("Invalid value for `pod_name`, must not be `None`")  # noqa: E501

        self._pod_name = pod_name

    @property
    def start_time(self):
        """Gets the start_time of this V1beta1ConditionCheckStatus.  # noqa: E501


        :return: The start_time of this V1beta1ConditionCheckStatus.  # noqa: E501
        :rtype: V1Time
        """
        return self._start_time

    @start_time.setter
    def start_time(self, start_time):
        """Sets the start_time of this V1beta1ConditionCheckStatus.


        :param start_time: The start_time of this V1beta1ConditionCheckStatus.  # noqa: E501
        :type: V1Time
        """

        self._start_time = start_time

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1beta1ConditionCheckStatus):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1beta1ConditionCheckStatus):
            return True

        return self.to_dict() != other.to_dict()



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

import setuptools

TESTS_REQUIRES = [
    'pytest',
    'pytest-tornasync',
    'mypy'
]

with open('requirements.txt') as f:
    REQUIRES = f.readlines()

setuptools.setup(
    name='tekton-pipeline',
    version='0.1.3',
    author="Tekton Authors",
    author_email='hejinchi@cn.ibm.com',
    license="Apache License Version 2.0",
    url="https://github.com/tektoncd/pipeline.git",
    description="Tekton Pipeline Python SDK",
    long_description="Python SDK for Tekton Pipeline.",
    packages=[
        'tekton_pipeline',
        'tekton_pipeline.api',
        'tekton_pipeline.constants',
        'tekton_pipeline.models',
        'tekton_pipeline.utils',
    ],
    package_data={'': ['requirements.txt']},
    include_package_data=True,
    zip_safe=False,
    classifiers=[
        'Intended Audience :: Developers',
        'Intended Audience :: Education',
        'Intended Audience :: Science/Research',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 3',
        "License :: OSI Approved :: Apache Software License",
        "Operating System :: OS Independent",
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Artificial Intelligence',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries',
        'Topic :: Software Development :: Libraries :: Python Modules',
    ],
    install_requires=REQUIRES,
    tests_require=TESTS_REQUIRES,
    extras_require={'test': TESTS_REQUIRES}
)



# Copyright 2020 The Tekton Authors
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.

# coding: utf-8

"""
    Tekton

    Tekton Pipeline  # noqa: E501

    The version of the OpenAPI document: v0.17.2
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest
import datetime

import tekton_pipeline
from tekton_pipeline.models.v1beta1_pipeline_run_list import V1beta1PipelineRunList  # noqa: E501
from tekton_pipeline.rest import ApiException

class TestV1beta1PipelineRunList(unittest.TestCase):
    """V1beta1PipelineRunList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional):
        """Test V1beta1PipelineRunList
            include_option is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # model = tekton_pipeline.models.v1beta1_pipeline_run_list.V1beta1PipelineRunList()  # noqa: E501
        if include_optional :
            return V1beta1PipelineRunList(
                api_version = '0', 
                items = [
                    tekton_pipeline.models.v1beta1/pipeline_run.v1beta1.PipelineRun(
                        api_version = '0', 
                        kind = '0', 
                        metadata = None, 
                        spec = tekton_pipeline.models.v1beta1/pipeline_run_spec.v1beta1.PipelineRunSpec(
                            params = [
                                tekton_pipeline.models.v1beta1/param.v1beta1.Param(
                                    name = '0', 
                                    value = tekton_pipeline.models.v1beta1/array_or_string.v1beta1.ArrayOrString(
                                        array_val = [
                                            '0'
                                            ], 
                                        string_val = '0', 
                                        type = '0', ), )
                                ], 
                            pipeline_ref = tekton_pipeline.models.v1beta1/pipeline_ref.v1beta1.PipelineRef(
                                api_version = '0', 
                                bundle = '0', 
                                name = '0', ), 
                            pipeline_spec = tekton_pipeline.models.v1beta1/pipeline_spec.v1beta1.PipelineSpec(
                                description = '0', 
                                finally = [
                                    tekton_pipeline.models.v1beta1/pipeline_task.v1beta1.PipelineTask(
                                        conditions = [
                                            tekton_pipeline.models.v1beta1/pipeline_task_condition.v1beta1.PipelineTaskCondition(
                                                condition_ref = '0', 
                                                resources = [
                                                    tekton_pipeline.models.v1beta1/pipeline_task_input_resource.v1beta1.PipelineTaskInputResource(
                                                        from = [
                                                            '0'
                                                            ], 
                                                        name = '0', 
                                                        resource = '0', )
                                                    ], )
                                            ], 
                                        name = '0', 
                                        resources = tekton_pipeline.models.v1beta1/pipeline_task_resources.v1beta1.PipelineTaskResources(
                                            inputs = [
                                                tekton_pipeline.models.v1beta1/pipeline_task_input_resource.v1beta1.PipelineTaskInputResource(
                                                    name = '0', 
                                                    resource = '0', )
                                                ], 
                                            outputs = [
                                                tekton_pipeline.models.v1beta1/pipeline_task_output_resource.v1beta1.PipelineTaskOutputResource(
                                                    name = '0', 
                                                    resource = '0', )
                                                ], ), 
                                        retries = 56, 
                                        run_after = [
                                            '0'
                                            ], 
                                        task_ref = tekton_pipeline.models.v1beta1/task_ref.v1beta1.TaskRef(
                                            api_version = '0', 
                                            bundle = '0', 
                                            kind = '0', 
                                            name = '0', ), 
                                        task_spec = tekton_pipeline.models.v1beta1/embedded_task.v1beta1.EmbeddedTask(
                                            description = '0', 
                                            metadata = tekton_pipeline.models.v1beta1/pipeline_task_metadata.v1beta1.PipelineTaskMetadata(
                                                annotations = {
                                                    'key' : '0'
                                                    }, 
                                                labels = {
                                                    'key' : '0'
                                                    }, ), 
                                            results = [
                                                tekton_pipeline.models.v1beta1/task_result.v1beta1.TaskResult(
                                                    description = '0', 
                                                    name = '0', )
                                                ], 
                                            sidecars = [
                                                tekton_pipeline.models.v1beta1/sidecar.v1beta1.Sidecar(
                                                    args = [
                                                        '0'
                                                        ], 
                                                    command = [
                                                        '0'
                                                        ], 
                                                    env = [
                                                        None
                                                        ], 
                                                    env_from = [
                                                        None
                                                        ], 
                                                    image = '0', 
                                                    image_pull_policy = '0', 
                                                    lifecycle = None, 
                                                    liveness_probe = None, 
                                                    name = '0', 
                                                    ports = [
                                                        None
                                                        ], 
                                                    readiness_probe = None, 
                                                    script = '0', 
                                                    security_context = None, 
                                                    startup_probe = None, 
                                                    stdin = True, 
                                                    stdin_once = True, 
                                                    termination_message_path = '0', 
                                                    termination_message_policy = '0', 
                                                    tty = True, 
                                                    volume_devices = [
                                                        None
                                                        ], 
                                                    volume_mounts = [
                                                        None
                                                        ], 
                                                    working_dir = '0', )
                                                ], 
                                            step_template = None, 
                                            steps = [
                                                tekton_pipeline.models.v1beta1/step.v1beta1.Step(
                                                    image = '0', 
                                                    image_pull_policy = '0', 
                                                    lifecycle = None, 
                                                    liveness_probe = None, 
                                                    name = '0', 
                                                    readiness_probe = None, 
                                                    script = '0', 
                                                    security_context = None, 
                                                    startup_probe = None, 
                                                    stdin = True, 
                                                    stdin_once = True, 
                                                    termination_message_path = '0', 
                                                    termination_message_policy = '0', 
                                                    timeout = None, 
                                                    tty = True, 
                                                    working_dir = '0', )
                                                ], 
                                            volumes = [
                                                None
                                                ], 
                                            workspaces = [
                                                tekton_pipeline.models.v1beta1/workspace_declaration.v1beta1.WorkspaceDeclaration(
                                                    description = '0', 
                                                    mount_path = '0', 
                                                    name = '0', 
                                                    optional = True, 
                                                    read_only = True, )
                                                ], ), 
                                        timeout = None, 
                                        when = [
                                            tekton_pipeline.models.v1beta1/when_expression.v1beta1.WhenExpression(
                                                input = '0', 
                                                operator = '0', 
                                                values = [
                                                    '0'
                                                    ], 
                                                input = '0', 
                                                operator = '0', 
                                                values = [
                                                    '0'
                                                    ], )
                                            ], 
                                        workspaces = [
                                            tekton_pipeline.models.v1beta1/workspace_pipeline_task_binding.v1beta1.WorkspacePipelineTaskBinding(
                                                name = '0', 
                                                sub_path = '0', 
                                                workspace = '0', )
                                            ], )
                                    ], 
                                resources = [
                                    tekton_pipeline.models.v1beta1/pipeline_declared_resource.v1beta1.PipelineDeclaredResource(
                                        name = '0', 
                                        optional = True, 
                                        type = '0', )
                                    ], 
                                results = [
                                    tekton_pipeline.models.v1beta1/pipeline_result.v1beta1.PipelineResult(
                                        description = '0', 
                                        name = '0', 
                                        value = '0', )
                                    ], 
                                tasks = [
                                    tekton_pipeline.models.v1beta1/pipeline_task.v1beta1.PipelineTask(
                                        name = '0', 
                                        retries = 56, 
                                        timeout = None, )
                                    ], 
                                workspaces = [
                                    tekton_pipeline.models.v1beta1/pipeline_workspace_declaration.v1beta1.PipelineWorkspaceDeclaration(
                                        description = '0', 
                                        name = '0', 
                                        optional = True, )
                                    ], ), 
                            pod_template = tekton_pipeline.models.pod/template.pod.Template(
                                affinity = None, 
                                automount_service_account_token = True, 
                                dns_config = None, 
                                dns_policy = '0', 
                                enable_service_links = True, 
                                host_network = True, 
                                image_pull_secrets = [
                                    None
                                    ], 
                                node_selector = {
                                    'key' : '0'
                                    }, 
                                priority_class_name = '0', 
                                runtime_class_name = '0', 
                                scheduler_name = '0', 
                                security_context = None, 
                                tolerations = [
                                    None
                                    ], ), 
                            resources = [
                                tekton_pipeline.models.v1beta1/pipeline_resource_binding.v1beta1.PipelineResourceBinding(
                                    name = '0', 
                                    resource_ref = tekton_pipeline.models.v1beta1/pipeline_resource_ref.v1beta1.PipelineResourceRef(
                                        api_version = '0', 
                                        name = '0', ), 
                                    resource_spec = tekton_pipeline.models.v1alpha1/pipeline_resource_spec.v1alpha1.PipelineResourceSpec(
                                        description = '0', 
                                        params = [
                                            tekton_pipeline.models.v1alpha1/resource_param.v1alpha1.ResourceParam(
                                                name = '0', 
                                                value = '0', )
                                            ], 
                                        secrets = [
                                            tekton_pipeline.models.v1alpha1/secret_param.v1alpha1.SecretParam(
                                                field_name = '0', 
                                                secret_key = '0', 
                                                secret_name = '0', )
                                            ], 
                                        type = '0', ), )
                                ], 
                            service_account_name = '0', 
                            service_account_names = [
                                tekton_pipeline.models.v1beta1/pipeline_run_spec_service_account_name.v1beta1.PipelineRunSpecServiceAccountName(
                                    service_account_name = '0', 
                                    task_name = '0', )
                                ], 
                            status = '0', 
                            task_run_specs = [
                                tekton_pipeline.models.v1beta1/pipeline_task_run_spec.v1beta1.PipelineTaskRunSpec(
                                    pipeline_task_name = '0', 
                                    task_pod_template = tekton_pipeline.models.pod/template.pod.Template(
                                        affinity = None, 
                                        automount_service_account_token = True, 
                                        dns_config = None, 
                                        dns_policy = '0', 
                                        enable_service_links = True, 
                                        host_network = True, 
                                        priority_class_name = '0', 
                                        runtime_class_name = '0', 
                                        scheduler_name = '0', 
                                        security_context = None, ), 
                                    task_service_account_name = '0', )
                                ], 
                            timeout = None, 
                            workspaces = [
                                tekton_pipeline.models.v1beta1/workspace_binding.v1beta1.WorkspaceBinding(
                                    config_map = None, 
                                    empty_dir = None, 
                                    name = '0', 
                                    persistent_volume_claim = None, 
                                    secret = None, 
                                    sub_path = '0', 
                                    volume_claim_template = None, )
                                ], ), 
                        status = tekton_pipeline.models.v1beta1/pipeline_run_status.v1beta1.PipelineRunStatus(
                            completion_time = None, 
                            observed_generation = 56, 
                            pipeline_results = [
                                tekton_pipeline.models.v1beta1/pipeline_run_result.v1beta1.PipelineRunResult(
                                    name = '0', 
                                    value = '0', )
                                ], 
                            skipped_tasks = [
                                tekton_pipeline.models.v1beta1/skipped_task.v1beta1.SkippedTask(
                                    name = '0', 
                                    when_expressions = [
                                        tekton_pipeline.models.v1beta1/when_expression.v1beta1.WhenExpression(
                                            input = '0', 
                                            operator = '0', 
                                            input = '0', 
                                            operator = '0', 
                                            values = [
                                                '0'
                                                ], )
                                        ], )
                                ], 
                            start_time = None, 
                            task_runs = {
                                'key' : tekton_pipeline.models.v1beta1/pipeline_run_task_run_status.v1beta1.PipelineRunTaskRunStatus(
                                    condition_checks = {
                                        'key' : tekton_pipeline.models.v1beta1/pipeline_run_condition_check_status.v1beta1.PipelineRunConditionCheckStatus(
                                            condition_name = '0', )
                                        }, 
                                    pipeline_task_name = '0', )
                                }, ), )
                    ], 
                kind = '0', 
                metadata = None
            )
        else :
            return V1beta1PipelineRunList(
        )

    def testV1beta1PipelineRunList(self):
        """Test V1beta1PipelineRunList"""
        inst_req_only = self.make_instance(include_optional=False)
        inst_req_and_optional = self.make_instance(include_optional=True)


if __name__ == '__main__':
    unittest.main()
